pub struct ZcosmicOutputConfigurationHeadV1 { /* private fields */ }wayland and Linux only.Expand description
Output configuration head extension object
Extension to zwlr_output_configuration_head_v1.
Adds additional/alternative parameters to the original zwlr_output_configuration_head_v1.
Once the original zwlr_output_configuration_head_v1 is destroyed this object will
become inert and all requests except release will be ignored.
This interface has no events.
Implementations
Sourceimpl ZcosmicOutputConfigurationHeadV1
impl ZcosmicOutputConfigurationHeadV1
Sourcepub fn set_scale_1000(&self, scale_1000: i32)
pub fn set_scale_1000(&self, scale_1000: i32)
set the scale multiplied by 1000
This request sets the head’s scale multiplied by 1000 for additional precision.
This request is meant to be used in place of zwlr_output_configuration_head_v1::set_scale.
Using set_scale and set_scale_1000 at once will thus raise an already_set error on the
original zwlr_output_configuration_head_v1.
Any request conflicting with set_scale will also conflict with set_scale_1000.
Sourcepub fn release(&self)
pub fn release(&self)
destroy the output configuration head
Using this request a client can tell the compositor that it is not going
to use the configuration object anymore. Already issued requests will
still be attached to the original zwlr_output_configuration_head_v1
until it is destroyed.
Sourcepub fn set_adaptive_sync_ext(&self, state: AdaptiveSyncStateExt)
pub fn set_adaptive_sync_ext(&self, state: AdaptiveSyncStateExt)
set adaptive sync state
This request requests a new adaptive sync state.
This request is meant to be used in place of zwlr_output_configuration_head_v1::set_adaptive_sync.
Using set_adaptive_sync and set_adaptive_sync_ext at once will thus raise an already_set error on the
original zwlr_output_configuration_head_v1.
Any request conflicting with set_adaptive_sync will also conflict with set_adaptive_sync_ext.